//! API representation of user information
//!
//! @author Pierre Hubert
use serde::Serialize;

use crate::data::user::{User, UserPageStatus};

#[derive(Serialize)]
#[allow(non_snake_case)]
pub struct APIUserInfo {
    userID: i64,
    firstName: String,
    lastName: String,
    publicPage: bool,
    openPage: bool,
    virtualDirectory: String,
}

impl APIUserInfo {
    pub fn new(info: User) -> APIUserInfo {
        APIUserInfo {
            userID: info.id,
            firstName: info.first_name,
            lastName: info.last_name,
            publicPage: info.status != UserPageStatus::PRIVATE,
            openPage: info.status == UserPageStatus::OPEN,
            virtualDirectory: info.virtual_directory.unwrap_or("".to_string())
        }
    }
}